==> haskell-bzlib-0.5.0.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bzlib
version: 0.5.0.5
id: bzlib-0.5.0.5-LhSa8mr35TvLPPGKdeRJgk
key: bzlib-0.5.0.5-LhSa8mr35TvLPPGKdeRJgk
license: BSD3
copyright: (c) 2006-2015 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
exposed: True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal
hidden-modules: Codec.Compression.BZip.Stream
abi: 54c50aef24f2b0fce7e0d7c9ce23e59f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bzlib-0.5.0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/bzlib-0.5.0.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/bzlib-0.5.0.5
hs-libraries: HSbzlib-0.5.0.5-LhSa8mr35TvLPPGKdeRJgk
extra-libraries:
    bz2
includes:
    bzlib.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html: /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bzlib-0.5.0.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bzlib
version: 0.5.0.5
id: bzlib-0.5.0.5-EN4Gp1pYAKe6GGDDoA97LY
key: bzlib-0.5.0.5-EN4Gp1pYAKe6GGDDoA97LY
license: BSD3
copyright: (c) 2006-2015 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
exposed: True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal
hidden-modules: Codec.Compression.BZip.Stream
abi: c4ca5904930786f109619a842c9cbce3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/bzlib-0.5.0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/bzlib-0.5.0.5
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/bzlib-0.5.0.5
hs-libraries: HSbzlib-0.5.0.5-EN4Gp1pYAKe6GGDDoA97LY
extra-libraries:
    bz2
includes:
    bzlib.h
depends:
    base-4.9.1.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html: /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
